ジャンプ先: 概要. 戻り値. キーワード. 関連. フラグ. MEL 例.

概要

timeEditorClipLayer [-addAttribute string] [-addLayer string] [-addObject string] [-allLayers] [-attribute string] [-attributeKeyable string] [-clipId int] [-index int] [-keySiblings] [-layerId int] [-layerName string] [-mode int] [-mute boolean] [-name] [-path string] [-removeAttribute string] [-removeLayer] [-removeObject string] [-resetSolo] [-setKeyframe] [-solo boolean] [-zeroKeying]

timeEditorClipLayer は、取り消し可能、照会可能、および編集可能です。

タイム エディタ(Time Editor)クリップ レイヤのコマンド

戻り値

stringコマンドの結果

照会モードでは、戻り値のタイプは照会されたフラグに基づきます。

キーワード

timeEditor, nle, layer

関連

timeEditor, timeEditorClip

フラグ

addAttribute, addLayer, addObject, allLayers, attribute, attributeKeyable, clipId, index, keySiblings, layerId, layerName, mode, mute, name, path, removeAttribute, removeLayer, removeObject, resetSolo, setKeyframe, solo, zeroKeying
ロング ネーム(ショート ネーム) 引数タイプ プロパティ
-addAttribute(-aa) string edit
指定された layerId のレイヤに、指定したプラグを追加します。
-addLayer(-al) string edit
名前が指定された新しいレイヤを追加します。
-addObject(-ao) string edit
指定された layerId のレイヤに、クリップ内にある、すべてのアトリビュートを持つ指定したオブジェクトを追加します。
-allLayers(-all) query
クリップ ID が指定されたすべてのレイヤを返します。
-attribute(-a) string editmultiuse
キー設定するアトリビュートのパスです。
-attributeKeyable(-ak) string query
指定したアトリビュートがキー設定可能であるかどうかを返します。
-clipId(-cid) int edit
このレイヤ コマンドが作用するクリップの ID です。

照会モードでは、このフラグは値を受け入れることができます。

-index(-idx) int edit
スタック内の特定の位置に新しいレイヤを追加するときに使用されるレイヤ インデックスです。
-keySiblings(-ks) edit
true に設定されている場合は、キー設定中に追加アトリビュートをキー設定することで、目的の結果を得ることができます。
-layerId(-lid) int edit
他の編集フラグと組み合わせて使用されるレイヤ ID です。

照会モードでは、このフラグは値を受け入れることができます。

-layerName(-ln) string queryedit
レイヤ名を編集します。照会モードでは、そのレイヤ ID とクリップ ID が指定されたレイヤ名を返します。
-mode(-m) int edit
アニメーション カーブによってクリップの再生速度をコントロールするには、次の手順を実行します。
  • 0: 加算
  • 1: 加算オーバーライド
  • 2: オーバーライド
  • 3: オーバーライド通過
-mute(-mu) boolean edit
レイヤ ID とクリップ ID が指定したレイヤをミュート/ミュート解除します。
-name(-n) query
レイヤ ID とクリップ ID が指定されたレイヤのアトリビュート名を照会します。
-path(-pt) string edit
操作するレイヤまたはクリップのフル パスです。例: composition1|track1|clip1|layer1; composition1|track1|group|track1|clip1。

照会モードでは、このフラグは値を受け入れることができます。

-removeAttribute(-ra) string edit
指定された layerId のレイヤから、指定したプラグを除去します。
-removeLayer(-rl) edit
ID を持つレイヤを除去します。
-removeObject(-ro) string edit
指定された layerId のレイヤから、クリップ内にある、すべてのアトリビュートを持つ指定したオブジェクトを除去します。
-resetSolo(-rs) edit
指定したクリップ ID 内のすべてのソロ レイヤをソロ化解除します。
-setKeyframe(-k) edit
クリップの指定したレイヤ上の指定アトリビュートにキーフレームを設定します。-clipId を使用して、指定したクリップを示します。-layerId を使用して、クリップの指定したレイヤを示します。-attribute を使用して、指定したアトリビュートを示します(アトリビュート フラグが使用されていない場合、すべてのアトリビュートがキー設定されます)。-zeroKeying を使用して、元のアニメーションからゼロ オフセットがキー設定されるべきであることを示します。
-solo(-sl) boolean edit
レイヤ ID とクリップ ID が指定されたレイヤをソロ化/ソロ化解除します。
-zeroKeying(-zk) edit
設定するキーが、元のアニメーションからゼロ オフセットされるべきかどうかを示します。

フラグはコマンドの作成モードで表示できます フラグはコマンドの編集モードで表示できます
フラグはコマンドの照会モードで表示できます コマンド内でフラグを複数回使用できます。

MEL 例

// Add an additive clip layer by clip ID
timeEditorClipLayer -e -clipId 1 -addLayer "Layer A" -mode 0;

// Add an additive clip layer by clip path
timeEditorClipLayer -e -path "Composition1|track1|Group|track1|Clip1" -addLayer "Layer B" -mode 0;

// Add an attribute to the given layer by clip ID and layer ID
timeEditorClipLayer -e -clipId 1 -addAttribute "cube.tx" -layerId 1;

// Add an attribute to the given layer path
timeEditorClipLayer -e -path "Composition1|track1|Clip1|Layer1" -addAttribute "cube.tx";

// Set key in the given layer
select cube;
move -r 10 0 0;
timeEditorClipLayer -e -setKeyframe -attribute "cube.tx" -clipId 1 -layerId 1;

// Remove layer attribute
timeEditorClipLayer -e -clipId 1 -removeAttribute "cube.tx" -layerId 1;

// Query the layer name
timeEditorClipLayer -clipId 1 -layerId 1 -q -layerName;

// Remove the specified layer by clip ID and layer ID
timeEditorClipLayer -e -clipId 1 -removeLayer -layerId 1;

// Remove the specified layer by layer path
timeEditorClipLayer -e -path "Composition1|track1|Clip1|Layer1" -removeLayer;